@@ -21,12 +21,12 @@ Take a look around F<examples/> folder for example tests that you can run
 agains your server.
 
 The general configuration should be done through the F<test-server.yaml> and should
-be managable by any non Perl awear admin (are there any?). Ofcourse you are free to
+be managable by any non Perl awear admin (are there any?). Of course you are free to
 put any other test that make sence for your server.
 
-The idea behind this is following. You run C<prove /etc/t> and everything is
+The idea behind this is following: You run C<prove /etc/t> and everything is
 fine. Server is up and running. Life is nice. Then somebody calls you at 3am...
-Ups what went wrong? You login to the server (if possible of course) and run
+Oups! What went wrong? You login to the server (if possible of course) and run
 the C<prove /etc/t> friend. Something failed? => fix it. Nothing failed?
 => write a test that will reveal that something is wrong && fix the problem
 of course ;). And then at 6am go happily to sleep again...
@@ -50,7 +50,7 @@ similar solutions like this...)
 use warnings;
 use strict;
 
-our $VERSION = '0.02_02';
+our $VERSION = '0.04_01';
 
 =head1 METHODS
 
@@ -108,7 +108,7 @@ query all nameserver-s in /etc/resolv.conf and make sure all are reachable.
 
 compare local machine time with a ntp server to make sure both are in the sync.
 
-For the idea thanks to Emmanuel Santiago Rodriguez.
+For the idea thanks to Emmanuel Rodriguez Santiago.
 
 =item 03_sites-ok.t
 
@@ -124,6 +124,19 @@ Check the output of the shell command with a regexp. Check the exit code.
 
 For the idea thanks to Aldo Calpini.
 
+=item 03_find-huge-files.t
+
+Check folders it there are not too many files and if the files (logs, tmp,
+etc.) didn't grow too large.
+
+=item 03_folder-file.t
+
+File directory permissions and sizes for a directories
+(e.g. Is cache dir writeable for httpd)
+
+For the idea thanks to Peter Hartl.
+
+
 =back
 
 =head1 sky
@@ -138,9 +151,7 @@ Do you have any? Send it! Or even better send the .t file.
 
 	* check if all the interfaces has dns revers rr that properly resolves back
 	* I should write some easy example test for non perl admins
-	* file directory permissions for all relevant application directories
-	  (e.g. Is cache dir writeable for httpd) (thanks Peter Hartl)
-	* check folders if the files (logs?) didn't grow too huge
+	* disk full check (using Filesys::DiskSpace||DiskFree ?)
 	
 	* create Test::Server::Smoke to try examples on smoke testing servers
 
@@ -150,6 +161,9 @@ L<http://testanything.org/>,
 L<http://en.wikipedia.org/wiki/Test_Anything_Protocol>
 and a book "Perl Testing: A Developer's Notebook"
 
+And if you like automated "thinks" check out also L<Sysadm::Install>
+for system admin scripting. Quite nice.
+
 =head1 AUTHOR
 
 Jozef Kutej
